/*
 * @Author: dminyi 1301963064@qq.com
 * @Date: 2024-08-09 09:59:43
 * @LastEditors: dminyi 1301963064@qq.com
 * @LastEditTime: 2024-08-31 16:52:26
 * @FilePath: \gzDyh\gz-customerSystem\src\views\basicInformation\organization\index.jsx
 * @Description: 来访登记
 */

import React, { useState, useRef, Fragment } from "react";
import NewPage from '@/components/NewPage';
import * as $$ from '@/utils/utility';
import "@arco-themes/react-gzzz/css/arco.css";
import '../index.less';
import { Space } from 'antd';
import { Button, Steps, Tabs, Message } from '@arco-design/web-react';
import VisitorRegister from './component/visitorRegister';
import Preview from './preview';

const Step = Steps.Step;

function saveDispute(data) {
	return $$.ax.request({ url: `casedraftInfo/caseDraftRegister`, type: 'post', service: 'mediate', data });
}

function getId() {
	return $$.ax.request({ url: `caseUtils/getNewTimeCaseId`, type: 'get', service: 'utils' });
}

function submitDispute(data) {
	return $$.ax.request({ url: `caseInfo/caseRegister`, type: 'post', service: 'mediate', data });
}


const Organization = () => {
	const formRef = useRef();

	const [isReview, setIsReview] = useState(false);//预览页面控制
	const [current, setCurrent] = useState(1);

	//提交信息，需要校验规则
	const handleSubmit = async () => {
		if (formRef.current) {
			formRef.current.validate(undefined, (errors, values) => {
				if (!errors) {
					const data = formRef.current.getFields()
					handleData(data).then(res => {
						reauestSubmit({
							...res,
							isSelfAccept: 0,
							isDraft: 0,
							operateType: 0,
						})
					})
				}
			});
		}
	}

	//保存草稿信息,不需要校验规则
	const handleSave = () => {
		if (formRef.current) {
			const data = formRef.current.getFields()
			handleData(data).then(res => {
				requestSave(res)
			})
		}
	}

	//数据处理
	const handleData = async (data) => {
		const { fakeData, ...newObj } = data
		if (data.id) {
			return {
				...newObj,
				personList: fakeData?.filter(item => item.perType === "15_020008-1" || item.perType === "15_020008-2"),
				agentList: fakeData?.filter(item => item.perType === "24_00006-1" || item.perType === "24_00006-2").map(item => {
					//personNameList用于查看详情显示代理人名字，不需要上传，去除
					const { personNameList, ...rest } = item
					return {
						...rest,
						personId: item.personId.join(',')
					}
				}),
			}
		} else {
			const res = await getId()
			if (res.type) {
				return {
					...newObj,
					personList: fakeData?.filter(item => item.perType === "15_020008-1" || item.perType === "15_020008-2"),
					agentList: fakeData?.filter(item => item.perType === "24_00006-1" || item.perType === "24_00006-2").map(item => {
						//personNameList用于查看详情显示代理人名字，不需要上传，去除
						const { personNameList, ...rest } = item
						return {
							...rest,
							personId: item.personId.join(',')
						}
					}),
					id: res.data
				}
			}
		}
	}

	//预览信息
	const handleReview = () => {
		setIsReview(!isReview)
	}

	function selfAcceptance() {
		$$.modalInfo({
			title: '自行受理确认',
			content: '确定自行受理吗？',
			okText: '确定受理',
			cancelText: '我再想想',
			onOk: async () => {
				setCurrent(3)
			},
		});
	}

	//保存请求
	const requestSave = async (data) => {
		const response = await saveDispute(data)
		if (response.type) {
			Message.success('保存草稿成功！')
		}
	}

	//提交请求
	const reauestSubmit = async (data) => {
		const response = await submitDispute(data)
		if (response.type) {
			Message.success('提交成功！')
			setCurrent(2)
		}
	}

	return (
		<div style={{ position: 'relative' }}>
			<NewPage
				pageHead={
					{ breadcrumbData: [{ title: '工作台' }, { title: '来访登记' }], title: '来访登记' }
				}
			>
				<Fragment>
					<div style={{ backgroundColor: '#fff', margin: '12px 16px 0px 16px', paddingTop: '16px', paddingLeft: '91px' }}>
						<Steps type='navigation' current={current}>
							<Step title='来访登记' disabled />
							<Step title='事件流转' disabled />
							<Step title='办理反馈' disabled />
							<Step title='结案审核' disabled />
							<Step title='当事人评价' disabled />
							<Step title='结案归档' disabled />
						</Steps>
					</div>
					<Preview style={{ display: isReview ? '' : 'none' }} />
					<VisitorRegister formRef={formRef} style={{ display: isReview ? 'none' : '' }} />
					<div className="dataSync-excel">
						<Space size="large" style={{ margin: '4px 14px' }}>
							<Button type="primary" style={{ backgroundColor: '#1A6FB8' }} onClick={handleSave} >保存</Button>
							<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }} onClick={handleReview}>预览</Button>
							<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }} onClick={handleSubmit}>提交</Button>
							<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }} onClick={() => selfAcceptance()}>自行受理</Button>
							<Button type='secondary' onClick={handleReview}>返回上级页面</Button>
						</Space>
					</div>
				</Fragment>
			</NewPage>
		</div>
	)
}

export default Organization;